@@ -15,16 +15,6 @@ class StringChain(object):
         assert self._assert_invariants()
         return self.len
 
-    def _assert_invariants(self):
-        _assert(self.ig >= 0, self.ig)
-        _assert(self.tailig >= 0, self.tailig)
-        _assert(self.len >= 0, self.len)
-        _assert((not self.d) or (self.d[0]), "First element is required to be non-empty.", self.d and self.d[0])
-        _assert((not self.d) or (self.ig < len(self.d[0])), self.ig, self.d and len(self.d[0]))
-        _assert((not self.d) or (self.tailig < len(self.d[-1])), self.tailig, self.d and len(self.d[-1]))
-        _assert(self.ig+self.len+self.tailig == sum([len(x) for x in self.d]), self.ig, self.len, self.tailig, sum([len(x) for x in self.d]))
-        return True
-        
     def append(self, s):
         """ Add s to the end of the chain. """
         assert self._assert_invariants()
@@ -95,6 +85,35 @@ class StringChain(object):
         assert n._assert_invariants()
         return n
 
+    def __str__(self):
+        """ Return the entire contents of this chain as a single
+        string. (Obviously this requires copying all of the bytes, so don't do
+        this unless you need to.) This has a side-effect of collecting all the
+        bytes in this StringChain object into a single string which is stored
+        in the first element of its internal deque. """
+        self._collapse()
+        if self.d:
+            return self.d[0]
+        else:
+            return ''
+
+    def copy(self):
+        n = self.__class__()
+        n.ig = self.ig
+        n.len = self.len
+        n.d = copy.copy(self.d)
+        return n
+
+    def _assert_invariants(self):
+        _assert(self.ig >= 0, self.ig)
+        _assert(self.tailig >= 0, self.tailig)
+        _assert(self.len >= 0, self.len)
+        _assert((not self.d) or (self.d[0]), "First element is required to be non-empty.", self.d and self.d[0])
+        _assert((not self.d) or (self.ig < len(self.d[0])), self.ig, self.d and len(self.d[0]))
+        _assert((not self.d) or (self.tailig < len(self.d[-1])), self.tailig, self.d and len(self.d[-1]))
+        _assert(self.ig+self.len+self.tailig == sum([len(x) for x in self.d]), self.ig, self.len, self.tailig, sum([len(x) for x in self.d]))
+        return True
+
     def _collapse(self):
         """ Concatenate all of the strings into one string and make that string
         be the only element of the chain. (Obviously this requires copying all
@@ -113,20 +132,3 @@ class StringChain(object):
             self.d.clear()
             self.d.append(newstr)
         assert self._assert_invariants()
-
-    def __str__(self):
-        """ Return the entire contents of this chain as a single string. (This
-        calls self._collapse() first then just returns a reference to the single
-        element of the chain.) """
-        self._collapse()
-        if self.d:
-            return self.d[0]
-        else:
-            return ''
-
-    def copy(self):
-        n = self.__class__()
-        n.ig = self.ig
-        n.len = self.len
-        n.d = copy.copy(self.d)
-        return n
